@@ -8,9 +8,11 @@ from __future__ import absolute_import
 
 from lxml import objectify
 
-from pptx.oxml import parse_xml_bytes
-from pptx.oxml.core import Element, SubElement
-from pptx.oxml.ns import nsdecls, nsmap, qn
+from . import parse_xml_bytes
+from ..enum.text import MSO_AUTO_SIZE
+from .ns import nsdecls, nsmap, qn
+from .shared import Element, SubElement
+from ..util import Centipoints
 
 
 class CT_Hyperlink(objectify.ObjectifiedElement):
@@ -144,6 +146,105 @@ class CT_TextBodyProperties(OxmlElement):
     schema.add_attr(Attribute('bIns', ST_Coordinate32))
     # lIns = Attribute(ST_Coordinate32)
 
+    def __setattr__(self, name, value):
+        """
+        Implement property setters
+        """
+        if name == 'autofit':
+            self._set_autofit(value)
+        else:
+            super(CT_TextBodyProperties, self).__setattr__(name, value)
+
+    @property
+    def autofit(self):
+        """
+        The autofit setting for the textframe
+        """
+        if self.noAutofit is not None:
+            return MSO_AUTO_SIZE.NONE
+        if self.normAutofit is not None:
+            return MSO_AUTO_SIZE.TEXT_TO_FIT_SHAPE
+        if self.spAutoFit is not None:
+            return MSO_AUTO_SIZE.SHAPE_TO_FIT_TEXT
+        return None
+
+    @property
+    def noAutofit(self):
+        """
+        The <a:noAutofit> child element, or None if not present.
+        """
+        return self.find(qn('a:noAutofit'))
+
+    @property
+    def normAutofit(self):
+        """
+        The <a:normAutofit> child element, or None if not present.
+        """
+        return self.find(qn('a:normAutofit'))
+
+    @property
+    def spAutoFit(self):
+        """
+        The <a:spAutoFit> child element, or None if not present.
+        """
+        return self.find(qn('a:spAutoFit'))
+
+    def _add_noAutofit(self):
+        noAutofit = Element('a:noAutofit')
+        self._insert_autofit(noAutofit)
+        return noAutofit
+
+    def _add_normAutofit(self):
+        normAutofit = Element('a:normAutofit')
+        self._insert_autofit(normAutofit)
+        return normAutofit
+
+    def _add_spAutoFit(self):
+        spAutoFit = Element('a:spAutoFit')
+        self._insert_autofit(spAutoFit)
+        return spAutoFit
+
+    def _first_child_found_in(self, *tagnames):
+        """
+        Return the first child found with tag in *tagnames*, or None if
+        not found.
+        """
+        for tagname in tagnames:
+            child = self.find(qn(tagname))
+            if child is not None:
+                return child
+        return None
+
+    def _insert_autofit(self, autofit_elm):
+        self._insert_element_before(
+            autofit_elm, 'a:scene3d', 'a:sp3d', 'a:flatTx', 'a:extLst'
+        )
+
+    def _insert_element_before(self, elm, *tagnames):
+        successor = self._first_child_found_in(*tagnames)
+        if successor is not None:
+            successor.addprevious(elm)
+        else:
+            self.append(elm)
+        return elm
+
+    def _remove_if_present(self, *tagnames):
+        for tagname in tagnames:
+            element = self.find(qn(tagname))
+            if element is not None:
+                self.remove(element)
+
+    def _set_autofit(self, value):
+        self._remove_if_present(
+            'a:noAutofit', 'a:normAutofit', 'a:spAutoFit'
+        )
+        if value == MSO_AUTO_SIZE.NONE:
+            self._add_noAutofit()
+        elif value == MSO_AUTO_SIZE.TEXT_TO_FIT_SHAPE:
+            self._add_normAutofit()
+        elif value == MSO_AUTO_SIZE.SHAPE_TO_FIT_TEXT:
+            self._add_spAutoFit()
+
 
 class CT_TextCharacterProperties(objectify.ObjectifiedElement):
     """
@@ -158,8 +259,8 @@ class CT_TextCharacterProperties(objectify.ObjectifiedElement):
         """
         if name in ('b', 'i'):
             return self._get_bool_attr(name)
-        elif name == 'eg_fillproperties':
-            return self._eg_fillproperties()
+        elif name == 'fill_element':
+            return self._eg_fill_properties()
         elif name == 'hlinkClick':
             return self.find(qn('a:hlinkClick'))
         else:
@@ -174,6 +275,9 @@ class CT_TextCharacterProperties(objectify.ObjectifiedElement):
             self._set_bool_attr(name, value)
         elif name == 'hlinkClick':
             self._set_hlinkClick(value)
+        elif name == 'sz':
+            emu_str = str(value.centipoints)
+            self.set(name, emu_str)
         else:
             super(CT_TextCharacterProperties, self).__setattr__(name, value)
 
@@ -269,6 +373,16 @@ class CT_TextCharacterProperties(objectify.ObjectifiedElement):
         """
         return self.find(qn('a:solidFill'))
 
+    @property
+    def sz(self):
+        """
+        The value of the ``sz`` attribute, or None if not present.
+        """
+        val = self.get('sz')
+        if val is None:
+            return None
+        return Centipoints(int(val))
+
     def _add_latin(self):
         """
         Return a newly added <a:latin> child element; assume one is not
@@ -310,7 +424,7 @@ class CT_TextCharacterProperties(objectify.ObjectifiedElement):
             self.insert(0, solidFill)
         return solidFill
 
-    def _eg_fillproperties(self):
+    def _eg_fill_properties(self):
         """
         Return the child representing the EG_FillProperties element group
         member in this element, or |None| if no such child is present.
