@@ -1,26 +1,29 @@
 # encoding: utf-8
 
-"""Test suite for pptx.text module."""
+"""
+Test suite for pptx.text module
+"""
 
 from __future__ import absolute_import, print_function
 
 import pytest
 
-from pptx.constants import MSO, PP
 from pptx.dml.color import ColorFormat
 from pptx.dml.fill import FillFormat
+from pptx.enum.text import MSO_ANCHOR, MSO_AUTO_SIZE, PP_ALIGN
 from pptx.opc.constants import RELATIONSHIP_TYPE as RT
 from pptx.opc.package import Part
 from pptx.oxml import parse_xml_bytes
-from pptx.oxml.ns import namespaces, nsdecls
+from pptx.oxml.ns import nsdecls, _nsmap as nsmap
 from pptx.oxml.text import (
     CT_RegularTextRun, CT_TextCharacterProperties, CT_TextParagraph
 )
 from pptx.text import _Font, _Hyperlink, _Paragraph, _Run, TextFrame
-from pptx.util import Inches
+from pptx.util import Inches, Pt
 
 from .oxml.unitdata.text import (
-    a_bodyPr, a_latin, a_txBody, a_p, a_pPr, a_t, an_hlinkClick, an_r, an_rPr
+    a_bodyPr, a_latin, a_txBody, a_noAutofit, a_normAutofit, a_p, a_pPr, a_t,
+    an_hlinkClick, an_r, an_rPr, an_spAutoFit
 )
 from .unitutil import (
     absjoin, actual_xml, class_mock, instance_mock, loose_mock,
@@ -28,11 +31,17 @@ from .unitutil import (
 )
 
 
-nsmap = namespaces('a', 'r', 'p')
-
-
 class DescribeTextFrame(object):
 
+    def it_knows_its_autosize_setting(self, autosize_get_fixture):
+        textframe, expected_value = autosize_get_fixture
+        assert textframe.auto_size == expected_value
+
+    def it_can_change_its_autosize_setting(self, autosize_set_fixture):
+        textframe, value, expected_xml = autosize_set_fixture
+        textframe.auto_size = value
+        assert actual_xml(textframe._txBody) == expected_xml
+
     def it_knows_the_number_of_paragraphs_it_contains(
             self, txBody, txBody_with_2_paras):
         assert len(TextFrame(txBody, None).paragraphs) == 1
@@ -99,7 +108,7 @@ class DescribeTextFrame(object):
     def it_can_change_its_vertical_anchor_setting(
             self, txBody, txBody_with_anchor_ctr_xml):
         textframe = TextFrame(txBody, None)
-        textframe.vertical_anchor = MSO.ANCHOR_MIDDLE
+        textframe.vertical_anchor = MSO_ANCHOR.MIDDLE
         assert actual_xml(textframe._txBody) == txBody_with_anchor_ctr_xml
 
     def it_can_change_the_word_wrap_setting(
@@ -127,6 +136,49 @@ class DescribeTextFrame(object):
 
     # fixtures ---------------------------------------------
 
+    @pytest.fixture(params=[
+        None,
+        MSO_AUTO_SIZE.NONE,
+        MSO_AUTO_SIZE.SHAPE_TO_FIT_TEXT,
+        MSO_AUTO_SIZE.TEXT_TO_FIT_SHAPE,
+    ])
+    def autosize_get_fixture(self, request):
+        auto_size = request.param
+        bodyPr_bldr = self.bodyPr_bldr_with_autofit(auto_size)
+        txBody = a_txBody().with_nsdecls().with_child(bodyPr_bldr).element
+        textframe = TextFrame(txBody, None)
+        expected_value = auto_size
+        return textframe, expected_value
+
+    @pytest.fixture(params=[
+        None,
+        MSO_AUTO_SIZE.NONE,
+        MSO_AUTO_SIZE.SHAPE_TO_FIT_TEXT,
+        MSO_AUTO_SIZE.TEXT_TO_FIT_SHAPE,
+    ])
+    def autosize_set_fixture(self, request):
+        auto_size = request.param
+        txBody = a_txBody().with_nsdecls().with_child(a_bodyPr()).element
+        textframe = TextFrame(txBody, None)
+        value = auto_size
+        expected_xml = (
+            a_txBody().with_nsdecls().with_child(
+                self.bodyPr_bldr_with_autofit(auto_size))
+        ).xml()
+        return textframe, value, expected_xml
+
+    # fixture components -----------------------------------
+
+    def bodyPr_bldr_with_autofit(self, auto_size):
+        bodyPr_bldr = a_bodyPr()
+        if auto_size == MSO_AUTO_SIZE.NONE:
+            bodyPr_bldr.with_child(a_noAutofit())
+        elif auto_size == MSO_AUTO_SIZE.SHAPE_TO_FIT_TEXT:
+            bodyPr_bldr.with_child(an_spAutoFit())
+        elif auto_size == MSO_AUTO_SIZE.TEXT_TO_FIT_SHAPE:
+            bodyPr_bldr.with_child(a_normAutofit())
+        return bodyPr_bldr
+
     @pytest.fixture
     def textframe(self, txBody):
         return TextFrame(txBody, None)
@@ -344,13 +396,62 @@ class Describe_Font(object):
         font.name = typeface
         assert actual_xml(font._rPr) == rPr_with_latin_xml
 
+    def it_knows_the_font_size(self, size_get_fixture):
+        font, expected_size = size_get_fixture
+        assert font.size == expected_size
+
     def it_can_set_the_font_size(self, font):
-        font.size = 2400
+        font.size = Pt(24)
         expected_xml = an_rPr().with_nsdecls().with_sz(2400).xml()
         assert actual_xml(font._rPr) == expected_xml
 
     # fixtures ---------------------------------------------
 
+    @pytest.fixture(params=[
+        (None, None),
+        (2400, 304800),
+    ])
+    def size_get_fixture(self, request):
+        sz_val, expected_size = request.param
+        rPr_bldr = an_rPr().with_nsdecls()
+        if sz_val is not None:
+            rPr_bldr.with_sz(sz_val)
+        font = _Font(rPr_bldr.element)
+        return font, expected_size
+
+    @pytest.fixture(params=[None, 'Foobar Light'])
+    def typeface_get_fixture(self, request):
+        typeface = request.param
+        rPr_bldr = an_rPr().with_nsdecls()
+        if typeface is not None:
+            rPr_bldr.with_child(a_latin().with_typeface(typeface))
+        rPr = rPr_bldr.element
+        font = _Font(rPr)
+        return font, typeface
+
+    @pytest.fixture(params=[
+        (None,            None),
+        (None,            'Foobar Light'),
+        ('Foobar Light',  'Foobar Medium'),
+        ('Foobar Medium', None),
+    ])
+    def typeface_set_fixture(self, request):
+        before_typeface, after_typeface = request.param
+        # starting font
+        rPr_bldr = an_rPr().with_nsdecls()
+        if before_typeface is not None:
+            rPr_bldr.with_child(a_latin().with_typeface(before_typeface))
+        rPr = rPr_bldr.element
+        font = _Font(rPr)
+        # expected XML
+        rPr_bldr = an_rPr().with_nsdecls()
+        if after_typeface is not None:
+            rPr_bldr.with_child(a_latin().with_typeface(after_typeface))
+        rPr_with_latin_xml = rPr_bldr.xml()
+        return font, after_typeface, rPr_with_latin_xml
+
+    # fixture components ---------------------------------------------
+
     @pytest.fixture
     def bold_font(self):
         bold_rPr = an_rPr().with_nsdecls().with_b(1).element
@@ -396,37 +497,6 @@ class Describe_Font(object):
     def rPr_xml(self):
         return an_rPr().with_nsdecls().xml()
 
-    @pytest.fixture(params=[None, 'Foobar Light'])
-    def typeface_get_fixture(self, request):
-        typeface = request.param
-        rPr_bldr = an_rPr().with_nsdecls()
-        if typeface is not None:
-            rPr_bldr.with_child(a_latin().with_typeface(typeface))
-        rPr = rPr_bldr.element
-        font = _Font(rPr)
-        return font, typeface
-
-    @pytest.fixture(params=[
-        (None,            None),
-        (None,            'Foobar Light'),
-        ('Foobar Light',  'Foobar Medium'),
-        ('Foobar Medium', None),
-    ])
-    def typeface_set_fixture(self, request):
-        before_typeface, after_typeface = request.param
-        # starting font
-        rPr_bldr = an_rPr().with_nsdecls()
-        if before_typeface is not None:
-            rPr_bldr.with_child(a_latin().with_typeface(before_typeface))
-        rPr = rPr_bldr.element
-        font = _Font(rPr)
-        # expected XML
-        rPr_bldr = an_rPr().with_nsdecls()
-        if after_typeface is not None:
-            rPr_bldr.with_child(a_latin().with_typeface(after_typeface))
-        rPr_with_latin_xml = rPr_bldr.xml()
-        return font, after_typeface, rPr_with_latin_xml
-
 
 class Describe_Hyperlink(object):
 
@@ -567,10 +637,10 @@ class Describe_Paragraph(object):
     def it_knows_the_alignment_setting_of_the_paragraph(
             self, paragraph, paragraph_with_algn):
         assert paragraph.alignment is None
-        assert paragraph_with_algn.alignment == PP.ALIGN_CENTER
+        assert paragraph_with_algn.alignment == PP_ALIGN.CENTER
 
     def it_can_change_its_alignment_setting(self, paragraph):
-        paragraph.alignment = PP.ALIGN_LEFT
+        paragraph.alignment = PP_ALIGN.LEFT
         assert paragraph._pPr.algn == 'l'
         paragraph.alignment = None
         assert paragraph._pPr.algn is None
